Module block

Module block 

Bitcoin block header and full block parsing — zero-copy.

Structs

BlkFileIter
Iterator over raw block messages in a Bitcoin Core blkNNNNN.dat file.
BlockHeader
An 80-byte Bitcoin block header — zero-copy.
BlockTxIter
A streaming iterator over the transactions in a raw block.

Constants

MAINNET_MAGIC
Bitcoin mainnet magic bytes.
MAX_BLOCK_BYTES
Maximum raw block payload size we will accept from a .dat file entry (sanity cap).
MAX_BLOCK_TXN
Maximum number of transactions per block (sanity cap for iteration).
SIGNET_MAGIC
Bitcoin signet magic bytes.
TESTNET_MAGIC
Bitcoin testnet3 magic bytes.