Module cursor

Module cursor 

Zero-copy cursor over a byte slice.

The Cursor type advances a shared reference into the input buffer without ever copying bytes. All returned slices have the lifetime of the original input data.

Structs

Cursor
Stateful, zero-copy cursor over an immutable byte slice.