ParseError

Enum ParseError 

#[non_exhaustive]
pub enum ParseError {
Show 13 variants UnexpectedEof { needed: usize, available: usize, }, InvalidVarInt, IntegerTooLarge { value: u64, }, OversizedData { size: usize, max: usize, }, UnsupportedVersion(i32), MagicMismatch { expected: [u8; 4], got: [u8; 4], }, InvalidSegwitFlag(u8), InvalidInputCount, TrailingBytes { remaining: usize, }, IncompleteTransactions { expected: usize, parsed: usize, }, InvalidCoinbase, InvalidCoinbaseCount { count: usize, }, Io { message: String, },
}
All errors that can occur during parsing.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnexpectedEof

Input ended before the structure was complete.

Fields

needed: usize

How many bytes were needed.

available: usize

How many were available.



InvalidVarInt

A variable-length integer had an invalid encoding.



IntegerTooLarge

A length/value was valid as a u64 but does not fit into the platform usize.

Fields

value: u64

The original integer value that could not fit into usize.



OversizedData

A script or data field exceeded the allowed maximum size.

Fields

size: usize

Actual size that was encountered.

max: usize

Maximum size allowed by the parser.



UnsupportedVersion(i32)

The block / transaction version is not supported by this parser.



MagicMismatch

The magic bytes at the start of a raw block did not match.

Fields

expected: [u8; 4]

The magic bytes this parser was configured to expect.

got: [u8; 4]

The magic bytes that were actually found in the input.



InvalidSegwitFlag(u8)

Segwit marker / flag bytes are invalid.

Tuple Fields

0: u8

The invalid flag byte.



InvalidInputCount

Transaction input count was invalid (e.g., zero in legacy format).



TrailingBytes

Extra bytes remained after parsing a structure in strict mode.

Fields

remaining: usize

Number of bytes left unread.



IncompleteTransactions

Not all transactions declared in the block were parsed.

Fields

expected: usize

Number of transactions declared in the block header.

parsed: usize

Number of transactions that were actually parsed.



InvalidCoinbase

Coinbase transaction had a non-empty txid reference (must be all-zero).



InvalidCoinbaseCount

A block contained an unexpected number of coinbase transactions.

Fields

count: usize

Number of coinbase transactions observed while parsing.



Io

An underlying I/O error occurred (only available with the std feature).

Fields

message: String

Human-readable I/O error message.