Bitcoin block header and full block parsing — zero-copy.
Structs
- BlkFile
Iter - Iterator over raw block messages in a Bitcoin Core
blkNNNNN.datfile. - Block
Header - An 80-byte Bitcoin block header — zero-copy.
- Block
TxIter - A streaming iterator over the transactions in a raw block.
Constants
- MAINNET_
MAGIC - Bitcoin mainnet magic bytes.
- MAX_
BLOCK_ BYTES - Maximum raw block payload size we will accept from a
.datfile entry (sanity cap). - MAX_
BLOCK_ TXN - Maximum number of transactions per block (sanity cap for iteration).
- SIGNET_
MAGIC - Bitcoin signet magic bytes.
- TESTNET_
MAGIC - Bitcoin testnet3 magic bytes.